Crate grovedb_path

source ·
GroveDB subtree path manipulation library.

Structs

  • Path to a GroveDB’s subtree with no owned data and cheap to clone.
  • Path to a GroveDB’s subtree.
  • (Reverse) iterator for a subtree path. Because of implementation details (one way link between derivations) it cannot effectively iterate from the most shallow path segment to the deepest, so it have to go in reverse direction.