pub struct SubtreePath<'b, B> { /* private fields */ }Expand description
Path to a GroveDB’s subtree with no owned data and cheap to clone.
Implementations
Sourceimpl SubtreePath<'static, [u8; 0]>
impl SubtreePath<'static, [u8; 0]>
Sourceimpl<B> SubtreePath<'_, B>
impl<B> SubtreePath<'_, B>
Sourceimpl<'b, B: AsRef<[u8]>> SubtreePath<'b, B>
impl<'b, B: AsRef<[u8]>> SubtreePath<'b, B>
Sourcepub fn derive_owned(&self) -> SubtreePathBuilder<'b, B>
pub fn derive_owned(&self) -> SubtreePathBuilder<'b, B>
Get a derived path that will reuse this Self as it’s base path and capable of owning data.
Sourcepub fn derive_owned_with_child<'s, S>(
&'b self,
segment: S,
) -> SubtreePathBuilder<'b, B>where
S: Into<CowLike<'s>>,
's: 'b,
pub fn derive_owned_with_child<'s, S>(
&'b self,
segment: S,
) -> SubtreePathBuilder<'b, B>where
S: Into<CowLike<'s>>,
's: 'b,
Get a derived path with a child path segment added.
Sourcepub fn derive_parent(&self) -> Option<(SubtreePath<'b, B>, &'b [u8])>
pub fn derive_parent(&self) -> Option<(SubtreePath<'b, B>, &'b [u8])>
Get a derived subtree path for a parent with care for base path slice
case. The main difference from SubtreePath::derive_parent is that
lifetime of returned Self if not limited to the scope where this
function was called so it’s possible to follow to ancestor paths
without keeping previous result as it still will link to 'b
(latest SubtreePath or initial slice of data).
Sourcepub fn into_reverse_iter(self) -> SubtreePathIter<'b, B> ⓘ
pub fn into_reverse_iter(self) -> SubtreePathIter<'b, B> ⓘ
Get a reverse path segments iterator.