Struct SubtreePathBuilder

pub struct SubtreePathBuilder<'b, B> { /* private fields */ }
Path to a GroveDB’s subtree.

Implementations

Source

impl SubtreePathBuilder<'static, [u8; 0]>

pub fn new() -> Self

Creates empty subtree path

Source

impl<B> SubtreePathBuilder<'_, B>

pub fn len(&self) -> usize

Returns the length of the subtree path.

pub fn is_empty(&self) -> bool

Returns whether the path is empty (the root tree).

Source

impl<'b, B: AsRef<[u8]>> SubtreePathBuilder<'b, B>

pub fn derive_owned(&'b self) -> SubtreePathBuilder<'b, B>

Get a derived path that will use another subtree path (or reuse the base slice) as it’s base, then could be edited in place.

pub fn derive_parent(&self) -> Option<(SubtreePath<'_, B>, &[u8])>

Get a derived path for a parent and a chopped segment. Returned SubtreePath will be linked to this SubtreePath because it might contain owned data and it has to outlive SubtreePath.

pub fn derive_owned_with_child<'s, S>( &'b self, segment: S, ) -> SubtreePathBuilder<'b, B>
where S: Into<CowLike<'s>>, 's: 'b,

Get a derived path with a child path segment added.

pub fn push_segment(&mut self, segment: &[u8])

Adds path segment in place.

pub fn reverse_iter(&'b self) -> SubtreePathIter<'b, B>

Returns an iterator for the subtree path by path segments.

pub fn to_vec(&self) -> Vec<Vec<u8>>

Collect path as a vector of vectors, but this actually negates all the benefits of this library.

pub fn is_root(&self) -> bool

Retuns true if the subtree path is empty, so it points to the root tree.